define([
	'app',
	'libraries/language'
], function(app, LANGUAGE) {
	app.controller("package",
		["$rootScope", "$scope", "$routeParams", "$location", "$timeout", "$interval", "jetapi", "SweetAlert",
			function($rootScope, $scope, $routeParams, $location, $timeout, $interval, jetapi, SweetAlert) {
				$scope.packages = ['jetbackup'];

				if(!$routeParams.package || $scope.packages.indexOf($routeParams.package) < 0) {
					$scope.changeView('/');
					return;
				}

				$scope.openTiers = false;
				$scope.package = {};

				$scope.install = function(tier) {

					if($scope.saveing) return;
					$scope.saveing = true;

					SweetAlert.swal({
						title: LANGUAGE.translate("Are you sure?"),
						text: LANGUAGE.translate("This package will be installed on this server"),
						icon: "warning",
						buttons: [LANGUAGE.translate("Cancel"), true]
					}, function(isConfirm){

						if (isConfirm)
						{
							jetapi.installPackage({ package: $scope.package.Package, tier: tier.tier }, function (response) {

								$scope.saveing = false;

								if(!response.success) {
									SweetAlert.error(LANGUAGE.translate("Error!"), LANGUAGE.translate(response.message));
									return;
								}

								$scope.package = response.data;
								SweetAlert.success(LANGUAGE.translate("Success!"), LANGUAGE.translate(response.message));
							});
						}
						else
						{
							$scope.saveing = false;
							SweetAlert.error(LANGUAGE.translate("Cancelled!"), LANGUAGE.translate("Installation cancelled"));
						}

					});

				};

				$scope.uninstall = function() {

					if($scope.saveing) return;
					$scope.saveing = true;

					SweetAlert.swal({
						title: LANGUAGE.translate("Are you sure?"),
						text: LANGUAGE.translate("This package will be deleted from this server"),
						icon: "warning",
						buttons: [LANGUAGE.translate("Cancel"), true]
					}, function(isConfirm){

						if (isConfirm)
						{
							jetapi.uninstallPackage({ package: $scope.package.Package }, function (response) {

								$scope.saveing = false;

								if(!response.success) {
									SweetAlert.error(LANGUAGE.translate("Error!"), LANGUAGE.translate(response.message));
									return;
								}

								$scope.package = response.data;
								SweetAlert.success(LANGUAGE.translate("Success!"), LANGUAGE.translate(response.message));
							});
						}
						else
						{
							$scope.saveing = false;
							SweetAlert.error(LANGUAGE.translate("Cancelled!"), LANGUAGE.translate("Uninstall cancelled"));
						}

					});
				};

				$scope.saveChanges = function() {

					if($scope.saveing) return;
					$scope.saveing = true;

					jetapi.changePackageTier({ package: $scope.package.Package, tier: $scope.package.CurrentTier }, function (response) {

						if(!response.success) {
							$scope.saveing = false;
							SweetAlert.error(LANGUAGE.translate("Error!"), LANGUAGE.translate(response.message));
							return;
						}

						jetapi.changePackageAutoUpdate({ package: $scope.package.Package, autoupdate: $scope.package.AutoUpdate }, function (response) {

							$scope.saveing = false;

							if(!response.success) {
								SweetAlert.error(LANGUAGE.translate("Error!"), LANGUAGE.translate(response.message));
								return;
							}

							SweetAlert.success(LANGUAGE.translate("Success!"), LANGUAGE.translate(response.message));
						});

					});
				};

				$scope.fetch = function () {
					jetapi.getPackage({ package: $routeParams.package }, function (response) {

						if(!response.success) {
							SweetAlert.error(LANGUAGE.translate("Error!"), LANGUAGE.translate(response.message));
							$scope.changeView('/');
							return;
						}

						$scope.package = response.data;
					});
				};

				$timeout($scope.fetch());
			}
		]
	);
});